@@ -1,7 +1,9 @@
+from typing import Any, List, Dict
 from .connection_factory_rabbitmq import ConnectionFactoryRabbitMQ
 from .channel_rabbitmq import ChannelRabbitMQ
 from amqp_client_python.exceptions import EventBusException
 from pika import SelectConnection, URLParameters
+from amqp_client_python.signals import Signal, Event
 from .ioloop_factory import IOLoopFactory
 import logging
 
@@ -13,15 +15,17 @@ class ConnectionRabbitMQ:
     _connection: SelectConnection
     _channel: ChannelRabbitMQ
 
-    def __init__(self) -> None:
+    def __init__(self, connection_type) -> None:
         self._connectionFactory = ConnectionFactoryRabbitMQ()
         self._connection = None
+        self.type = connection_type
+        self.signal = Signal()
         self.ioloop_factory = IOLoopFactory
         self.ioloop_factory.add_reconnection(self.reconnect)
         self._stopping = False
-        self._channel = ChannelRabbitMQ()
+        self._channel = ChannelRabbitMQ(channel_type=self.type)
         self._uri = None
-        self.backup = {
+        self.backup: Dict[str, Dict[str, Any]] = {
             "exchange": {},
             "queue": {},
             "subscribe": {},
@@ -145,6 +149,7 @@ class ConnectionRabbitMQ:
         :param pika.SelectConnection _unused_connection: The connection
         """
         LOGGER.debug("Connection opened")
+        self.signal.emmit(Event.CONNECTED, condiction=self.type)
         if not self.channel_is_open():
             self.channel_open()
         # self.pause()
@@ -190,6 +195,7 @@ class ConnectionRabbitMQ:
         if not self.channel_is_open():
             self._channel.open(self, callback)
 
+    @property
     def is_open(self) -> bool:
         return self._connection and self._connection.is_open
 
@@ -197,9 +203,9 @@ class ConnectionRabbitMQ:
         return self._channel and self._channel.is_open()
 
     def publish(self, exchange_name: str, routing_key: str, message: str):
-        if not self.is_open():
+        if not self.ioloop_is_open:
             raise EventBusException("No connection open!")
-        if not self._channel.is_open():
+        if not self._channel.is_open:
             raise EventBusException("No channel open!")
         return self._channel.publish(exchange_name, routing_key, message)
 
@@ -211,9 +217,9 @@ class ConnectionRabbitMQ:
         callback,
         auto_ack=True,
     ):
-        if not self.is_open():
+        if not self.is_open:
             raise EventBusException("No connection open!")
-        if not self._channel.is_open():
+        if not self._channel.is_open:
             raise EventBusException("No channel open!")
         self.backup["subscribe"][routing_key] = {
             "exchange": exchange_name,
@@ -229,14 +235,14 @@ class ConnectionRabbitMQ:
         self,
         exchange_name: str,
         routing_key: str,
-        message: str,
+        message: List[Any],
         content_type,
         future,
         timeout,
     ):
-        if not self.is_open():
+        if not self.is_open:
             self.reset()
-        if not self._channel.is_open():
+        if not self._channel.is_open:
             self.channel_open()
         return self._channel.rpc_client(
             exchange_name,
@@ -250,9 +256,9 @@ class ConnectionRabbitMQ:
     def rpc_subscribe(
         self, queue_name: str, exchange_name: str, routing_key: str, callback
     ):
-        if not self.is_open():
+        if not self.is_open:
             raise EventBusException("No connection open!")
-        if not self._channel.is_open():
+        if not self._channel.is_open:
             raise EventBusException("No channel open!")
         self.backup["rpc_subscribe"][routing_key] = {
             "exchange": exchange_name,
